package com.ynet.life.file.parser;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import java.io.BufferedWriter;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonDownloadCSVFileParser.class */
public class CommonDownloadCSVFileParser implements CommonDownloadFileParserInterface {
    private static final String COMMA = ",";

    @Override // com.ynet.life.file.parser.CommonDownloadFileParserInterface
    public byte[] writeToFile(List titles, List recordList, List outputFields, List outputFormats, List lastList, String filePathName, String encoding) throws TranFailException {
        StringBuffer fileContent = new StringBuffer();
        if (titles != null) {
            for (int i = 0; i < titles.size(); i++) {
                fileContent.append(titles.get(i)).append(COMMA);
            }
            StringBuffer stringBuffer = new StringBuffer(fileContent.substring(0, fileContent.length() - 1));
            fileContent = stringBuffer;
            stringBuffer.append(LifeFile.LINE_SEPARATOR);
        }
        if (recordList != null) {
            Iterator iterator = recordList.iterator();
            while (iterator.hasNext()) {
                Map record = (Map) iterator.next();
                for (int i2 = 0; i2 < outputFields.size(); i2++) {
                    Object obj = record.get(outputFields.get(i2)) == null ? "" : record.get(outputFields.get(i2));
                    String format = (String) outputFormats.get(i2);
                    String fieldValue = DownloadFileParserUtil.transformFormat(obj.toString(), format);
                    if ("2".equals(format) || "".equals(obj)) {
                        fileContent.append("\"").append(fieldValue.trim()).append("\",");
                    } else {
                        fileContent.append(fieldValue.trim()).append("\t,");
                    }
                }
                StringBuffer stringBuffer2 = new StringBuffer(fileContent.substring(0, fileContent.length() - 1));
                fileContent = stringBuffer2;
                stringBuffer2.append(LifeFile.LINE_SEPARATOR);
            }
        }
        byte[] b = writeStringToFile(filePathName, fileContent.toString(), encoding, false);
        if (b.length > 0) {
            return b;
        }
        return null;
    }

    public static byte[] writeStringToFile(String filePathName, String fileContent, String encoding, boolean append) throws TranFailException {
        BufferedWriter fileWriter = null;
        FileOutputStream outFile = null;
        OutputStreamWriter outWriter = null;
        try {
            try {
                outFile = new FileOutputStream(filePathName, append);
                outWriter = new OutputStreamWriter(outFile, encoding);
                BufferedWriter bufferedWriter = new BufferedWriter(outWriter);
                fileWriter = bufferedWriter;
                bufferedWriter.write(fileContent);
                byte[] bytes = fileWriter.toString().getBytes();
                try {
                    fileWriter.close();
                    outWriter.close();
                    outFile.close();
                } catch (IOException ex) {
                    Trace.logWarning("LifeFile", "文件对象关闭异常", ex);
                }
                return bytes;
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileWriter != null) {
                try {
                    fileWriter.close();
                } catch (IOException ex3) {
                    Trace.logWarning("LifeFile", "文件对象关闭异常", ex3);
                    throw th;
                }
            }
            if (outWriter != null) {
                outWriter.close();
            }
            if (outFile != null) {
                outFile.close();
            }
            throw th;
        }
    }
}
